descope.logging
===============

.. automodule:: descope.logging
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members:
        _configure_logger,
        _get_library_name,
        _get_library_root_logger,
        _configure_library_root_logger,
        set_verbosity